Python: module JsonRpc

JsonRpc (version 1.0.0) | index jsonrpc.py

`This tool runs CLI scripts and displays output in a Web Interface.
This module implements JSON RPC on WebScripts.`

Classes
`` |  | builtins.object JsonRpc
class JsonRpc(builtins.object)
`` | `JsonRpc(environ: os._Environ, user: ~User, server: ~Server, filename: str, calls: Union[List[Dict[str, Any]], Dict[str, Any]], inputs: List[str], csrf_token: str = None) -&gt; Tuple[str, Dict[str, str], str] This class implements JSON RPC for the WebScripts Server.`
| Class methods defined here: execute_call(json: Dict[str, Any]) -> Dict[str, Any] from builtins.type `This function performs a JSON RPC call.` register_function(function: collections.abc.Callable, name: str = None) from builtins.type `This function adds a new function in the JSON RPC calls.` Static methods defined here: __new__(cls: type, environ: os._Environ, user: ~User, server: ~Server, filename: str, calls: Union[List[Dict[str, Any]], Dict[str, Any]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `Create and return a new object. See help(type) for accurate signature.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __annotations__ = {'functions': typing.Dict[str, collections.abc.Callable]} functions = {'call': <function test_call>, 'test_args_dict': <function test_argument_dict>, 'test_argument_list': <function test_argument_list>}

Data
`` |  | __all__ = ['JsonRpc'] __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool runs CLI scripts and displays output ...\n\nThis module implements JSON RPC on WebScripts.\n' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts'

Author
`` |  | Maurice Lambert